nav.context-menu {
	display: none;
	position: absolute;
	z-index: 10;
	background: rgb(255,255,255);
	margin: 0;
	padding: 0;
	border: none;
	border-radius: 2px;
	box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}

nav.context-menu.active {
	display: block;
}

nav.context-menu ul {
	margin: 0;
	padding: 0;
	list-style-type: none;
}

nav.context-menu ul li {
	display:block;
	line-height:22px;
	padding:5px 20px;
	border-bottom:1px solid #E0E0E0;
}

nav.context-menu ul li.disabled {
	color: #A0A0A0;
}

nav.context-menu ul > li > ul {
	display: none;
	z-index: 10;
	position: absolute;
	background:white;
	border-radius: 2px;
	box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}

nav.context-menu ul > li > ul > li {
	line-height:18px;
	font-size:85%;
	padding:2px 10px;
}

nav.context-menu ul > li.subactive > ul {
	display: block;
	width:180px;
}

nav.context-menu ul li:hover, nav.context-menu ul > li.subactive > ul > li:hover {
	background-color:#CCCCCC;
	cursor:pointer;
}
