function E(e){return document.getElementById(e)}function encode(e){return e.replace(/[\x26\x0A\<>'"]/g,function(e){return"&#"+e.charCodeAt(0)+";"})}function clickableOffsets(e){return console.error("Using clickableOffsets(str) no longer work"),console.trace(),e=(e=(e=(e=e.replace(/0x([a-zA-Z0-9]*)/g,"<a href='javascript:seek(\"0x$1\")'>0x$1</a>")).replace(/sym\.([\.a-zA-Z0-9_]*)/g,"<a href='javascript:seek(\"sym.$1\")'>sym.$1</a>")).replace(/fcn\.([\.a-zA-Z0-9_]*)/g,"<a href='javascript:seek(\"fcn.$1\")'>fcn.$1</a>")).replace(/str\.([\.a-zA-Z0-9_]*)/g,"<a href='javascript:seek(\"str.$1\")'>str.$1</a>")}