div.mydropdown > div > .ddcontent {
    display: none;
    position: absolute;
    right:0;
    background-color: #f9f9f9;
    box-shadow: 0px 8px 16px 0px rgba(0,0,0,0.2);
    width: 400px;
	margin:0;
	padding:0;
}

div.mydropdown, div.mydropdown div {
	margin: 0;
	min-width: 0;
}

div.mydropdown.is-focused > div {
	padding:0;
	margin-left:12px;
}

ul.ddcontent li {
	display:block;
	padding:5px 10px;
	margin:0;
	border-bottom: 1px solid silver;
	overflow: hidden;
	font-family: "DejaVu Sans Mono";
	font-size:11px;
}

ul.ddcontent li.active {
	background-color: #eeeeee;
}

ul.ddcontent li:last-child {
	border:none;
}
