@font-face {
	font-family: 'Roboto';
	font-style: italic;
	font-weight: 400;
	font-display: auto;
	font-stretch: normal;
	src: url(Roboto-italic-400.woff) format('woff');
	unicode-range: U+0-10FFFF;
}

@font-face {
	font-family: 'Roboto';
	font-style: italic;
	font-weight: 700;
	font-display: auto;
	font-stretch: normal;
	src: url(Roboto-italic-700.woff) format('woff');
	unicode-range: U+0-10FFFF;
}

@font-face {
	font-family: 'Roboto';
	font-style: normal;
	font-weight: 100;
	font-display: auto;
	font-stretch: normal;
	src: url(Roboto-normal-100.woff) format('woff');
	unicode-range: U+0-10FFFF;
}

@font-face {
	font-family: 'Roboto';
	font-style: normal;
	font-weight: 300;
	font-display: auto;
	font-stretch: normal;
	src: url(Roboto-normal-300.woff) format('woff');
	unicode-range: U+0-10FFFF;
}

@font-face {
	font-family: 'Roboto';
	font-style: normal;
	font-weight: 400;
	font-display: auto;
	font-stretch: normal;
	src: url(Roboto-normal-400.woff) format('woff');
	unicode-range: U+0-10FFFF;
}

@font-face {
	font-family: 'Roboto';
	font-style: normal;
	font-weight: 500;
	font-display: auto;
	font-stretch: normal;
	src: url(Roboto-normal-500.woff) format('woff');
	unicode-range: U+0-10FFFF;
}

@font-face {
	font-family: 'Roboto';
	font-style: normal;
	font-weight: 700;
	font-display: auto;
	font-stretch: normal;
	src: url(Roboto-normal-700.woff) format('woff');
	unicode-range: U+0-10FFFF;
}

@font-face {
	font-family: 'Roboto';
	font-style: normal;
	font-weight: 900;
	font-display: auto;
	font-stretch: normal;
	src: url(Roboto-normal-900.woff) format('woff');
	unicode-range: U+0-10FFFF;
}

