.disasmPanel {
	background-color: rgb(16, 16, 16);
	color: white;
	overflow: hidden !important;
}

.disasm.flex-controls {
	border-bottom:1px dotted white;
	background:white;
	color:black;
	height:80px;
}

.disasm.flex-controls .button-controls-disasm {
	padding:16px;
	display: inline-block;
}

.disasm.flex-body {
	top:80px;
	line-height: 1em;
}

.disasm.flex-body {
	font-family: "Roboto Mono", "DejaVu Sans Mono", Console, Courier New, monospace;
	font-weight:bold;
}

div.disasm span.offset, div.disasm span.fcn {
	display: inline-block;
	width: 100%;
}

/*
div.disasm span:hover.offset, div.disasm span:hover.fcn {
	background-color: rgb(16, 16, 16);
}
*/

.currentOffset {
	background-color: rgb(64, 64, 64);
}

ul#disasm-history {
	display: inline-block;
}

ul#disasm-history li {
	display: inline-block;
	line-height: 1em;
	font-size:85%;
	padding: 0 4px;
	margin: 0 3px;

	background:white;
	border-radius: 2px;
	box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}

ul#disasm-history li.active {
	background-color: #E0E0E0;
}

ul#disasm-history li:hover {
	background-color: #CCCCCC;
	cursor: pointer;
}

table.disasm-table-dialog {
	border-collapse: collapse;
}

table.disasm-table-dialog, table.disasm-table-dialog th, table.disasm-table-dialog td {
	border: 1px solid #A0A0A0;
}

table.disasm-table-dialog td {
	font-family: "Roboto Mono", "DejaVu Sans Mono", Console, Courier New, monospace;
	text-align: center;
}
