#ifndef R_VERSION_H
#define R_VERSION_H 1
#define R_MESON_VERSION "1.10.1"
#define R2_VERSION_MAJOR 6
#define R2_VERSION_MINOR 1
#define R2_VERSION_PATCH 2
#define R2_VERSION_NUMBER 60102
#define R2_VERSION_COMMIT 35478
#define R2_VERSION "6.1.2"
#define R2_GITTAP "6.1.2"
#define R2_GITTIP "fe5b09706cf30e4593821b1b2dc1bfe1b8c00735"
#define R2_BIRTH "2026-03-31__10:33:00"
#endif
